@@ -13,16 +13,13 @@
 #'  }
 #' @examples
 #' \donttest{
-#' cik_search("cloudera")
+#' try(cik_search("cloudera"))
 #' }
 #' @export
 cik_search <- function(company) {
   href <- paste0("https://www.sec.gov/cgi-bin/cik_lookup",
                 "?company=", URLencode(company, reserved = TRUE))
-  res <- httr::GET(href)
-  if (res$status != "200") {
-    stop("Unable to reach the SEC cik lookup endpoint (https://www.sec.gov/cgi-bin/cik_lookup)")
-  }
+  res <- edgar_GET(href)
   doc <- xml2::read_html(res, base_url = href, options = "HUGE")
 
   entries_xpath <- "//pre/a[starts-with(@href,'browse-edgar')]"
