@@ -1,8 +1,8 @@
 context("running company_information")
 
-with_mock_API({
+with_mock_api({
 test_that("running ", {
-            expect_error(company_information("EAR"))
+            expect_error(company_information("BAD"))
             res <- company_information("EA")
             expect_is(res, "data.frame")
 
