@@ -1,6 +1,6 @@
 context("running effectiveness")
 
-with_mock_API({
+with_mock_api({
   test_that("running ", {
     res <- effectiveness()
     expect_length(res, 8)
